==> bitcoin-0.21.1.knots20210629.tar.gz: bitcoin-0.21.1.knots20210629/src/qt/locale/bitcoin_gu.ts <==
<TS language="gu" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>નવું સરનામું બનાવો</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>નવું</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>હાલમાં પસંદ કરેલા સરનામાંને સિસ્ટમ ક્લિપબોર્ડ પર નકલ કરો</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp; નકલ કરો</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp; બંધ કરો</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>સૂચિમાંથી હાલમાં પસંદ કરેલું સરનામું કાઢી નાખો</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>શોધવા માટે સરનામું અથવા લેબલ દાખલ કરો</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>હાલ માં પસંદ કરેલ માહિતી ને ફાઇલમાં નિકાસ કરો</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp; નિકાસ કરો</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp; કાઢી નાખો</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>સિક્કા મોકલવા માટે સરનામું પસંદ કરો</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>સિક્કા મેળવવા માટે સરનામું પસંદ કરો</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp; પસંદ કરો</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>મોકલવા માટે ના સરનામાં</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>મેળવવા માટે ના સરનામાં</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>આ તમારા ચુકવણી કરવા માટે ના સરનામાં છે, હંમેશા કિંમત અને મોકલવાના ના સરનામાં ચકાસી લેવા સિક્કા આપતા પહેલા.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp; સરનામુ નકલ કરો</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>નકલ &amp; લેબલ</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp; બદલો</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>સરનામાં ની સૂચિ નો નિકાસ કરો</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>અલ્પવિરામ થી જુદા પડલી માહિતી ની યાદી (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>નિકાસ ની પ્ર્રાક્રિયા નિષ્ફળ ગયેલ છે</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>ચિઠ્ઠી</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>સરનામુ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>લેબલ નથી</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>ગુપ્ત શબ્દ માટે નુ ડાયલોગ</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>ગુપ્ત શબ્દ દાખલ કરો </translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>નવો ગુપ્ત શબ્દ</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>ગુપ્ત શબ્દ ફરી નાખો</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>ગુપ્ત શબ્દ જોવો</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>સાંકેતિક પાકીટ</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>પાકીટ અવલોકન જરુરી છે પાકીટ ઓપન કરવા માટે</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>પાકીટ ખુલ્લુ</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>પાકીટ કામગીરી જરુરી છે ગુપ્ત પાકીટ ડિક્રિપ્ટ કરવા માટે</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>ડિક્રિપ્ટ પાકીટ</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>ગુપ્ત શબ્દ બદલો</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>એન્ક્રિપ્શન ખાતરી કરો </translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>ચેતવણી: જો તમે તમારું વletલેટ એન્ક્રિપ્ટ કરો છો અને તમારો પાસફ્રેઝ ખોવાઈ જાય છે, તો તમે તમારા બધા બિટકોઇન્સ ગુમાવશો!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>શું તમે ખરેખર તમારા પાકીટને એન્ક્રિપ્ટ કરવા માંગો છો?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>પાકીટ એન્ક્રિપ્ટ થયેલ</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;મોકલવા માટે ના સરનામાં</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;મેળવવા માટે ના સરનામાં</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp; સરનામુ નકલ કરો</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>નકલ &amp; લેબલ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>લેબલ નથી</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Encrypt Wallet</source>
        <translation>સાંકેતિક પાકીટ</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;ચિઠ્ઠી</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;સરનામુ</translation>
    </message>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>સરનામુ</translation>
    </message>
</context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished"> બંધ કરો</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation>&amp; સરનામુ નકલ કરો</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;ચિઠ્ઠી:</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp; સરનામુ નકલ કરો</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>નકલ &amp; લેબલ</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">સરનામુ:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">ચિઠ્ઠી:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">&amp; સરનામુ નકલ કરો</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>ચિઠ્ઠી</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>લેબલ નથી</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Choose...</source>
        <translation type="unfinished"> પસંદ કરો...</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>લેબલ નથી</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;ચિઠ્ઠી:</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>ચિઠ્ઠી</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>લેબલ નથી</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp; સરનામુ નકલ કરો</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>નકલ &amp; લેબલ</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>અલ્પવિરામ થી જુદા પડલી માહિતી ની યાદી (*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ચિઠ્ઠી</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>સરનામુ</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>નિકાસ ની પ્ર્રાક્રિયા નિષ્ફળ ગયેલ છે</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp; નિકાસ કરો</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>હાલ માં પસંદ કરેલ માહિતી ને ફાઇલમાં નિકાસ કરો</translation>
    </message>
    </context>
</TS>

==> bitcoin-21.2.knots20210629.tar.gz: bitcoin-21.2.knots20210629/src/qt/locale/bitcoin_gu.ts <==
<TS language="gu" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>નવું સરનામું બનાવો</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>નવું</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>હાલમાં પસંદ કરેલા સરનામાંને સિસ્ટમ ક્લિપબોર્ડ પર નકલ કરો</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp; નકલ કરો</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp; બંધ કરો</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>સૂચિમાંથી હાલમાં પસંદ કરેલું સરનામું કાઢી નાખો</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>શોધવા માટે સરનામું અથવા લેબલ દાખલ કરો</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>હાલ માં પસંદ કરેલ માહિતી ને ફાઇલમાં નિકાસ કરો</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp; નિકાસ કરો</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp; કાઢી નાખો</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>સિક્કા મોકલવા માટે સરનામું પસંદ કરો</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>સિક્કા મેળવવા માટે સરનામું પસંદ કરો</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp; પસંદ કરો</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>મોકલવા માટે ના સરનામાં</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>મેળવવા માટે ના સરનામાં</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>આ તમારા ચુકવણી કરવા માટે ના સરનામાં છે, હંમેશા કિંમત અને મોકલવાના ના સરનામાં ચકાસી લેવા સિક્કા આપતા પહેલા.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp; સરનામુ નકલ કરો</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>નકલ &amp; લેબલ</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp; બદલો</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>સરનામાં ની સૂચિ નો નિકાસ કરો</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>અલ્પવિરામ થી જુદા પડલી માહિતી ની યાદી (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>નિકાસ ની પ્ર્રાક્રિયા નિષ્ફળ ગયેલ છે</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>ચિઠ્ઠી</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>સરનામુ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>લેબલ નથી</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>ગુપ્ત શબ્દ માટે નુ ડાયલોગ</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>ગુપ્ત શબ્દ દાખલ કરો </translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>નવો ગુપ્ત શબ્દ</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>ગુપ્ત શબ્દ ફરી નાખો</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>ગુપ્ત શબ્દ જોવો</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>સાંકેતિક પાકીટ</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>પાકીટ અવલોકન જરુરી છે પાકીટ ઓપન કરવા માટે</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>પાકીટ ખુલ્લુ</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>પાકીટ કામગીરી જરુરી છે ગુપ્ત પાકીટ ડિક્રિપ્ટ કરવા માટે</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>ડિક્રિપ્ટ પાકીટ</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>ગુપ્ત શબ્દ બદલો</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>એન્ક્રિપ્શન ખાતરી કરો </translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>ચેતવણી: જો તમે તમારું વletલેટ એન્ક્રિપ્ટ કરો છો અને તમારો પાસફ્રેઝ ખોવાઈ જાય છે, તો તમે તમારા બધા બિટકોઇન્સ ગુમાવશો!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>શું તમે ખરેખર તમારા પાકીટને એન્ક્રિપ્ટ કરવા માંગો છો?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>પાકીટ એન્ક્રિપ્ટ થયેલ</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation type="unfinished">&amp;સાંકેતિક પાકીટ...</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;મોકલવા માટે ના સરનામાં</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;મેળવવા માટે ના સરનામાં</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp; સરનામુ નકલ કરો</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>નકલ &amp; લેબલ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>લેબલ નથી</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Encrypt Wallet</source>
        <translation>સાંકેતિક પાકીટ</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;ચિઠ્ઠી</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;સરનામુ</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>સરનામુ</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished"> બંધ કરો</translation>
    </message>
    </context>
<context>
    <name>PairingPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation>&amp; સરનામુ નકલ કરો</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;ચિઠ્ઠી:</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp; સરનામુ નકલ કરો</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>નકલ &amp; લેબલ</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">સરનામુ:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">ચિઠ્ઠી:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">&amp; સરનામુ નકલ કરો</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>ચિઠ્ઠી</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>લેબલ નથી</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Choose...</source>
        <translation type="unfinished"> પસંદ કરો...</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>લેબલ નથી</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;ચિઠ્ઠી:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>ચિઠ્ઠી</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>લેબલ નથી</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp; સરનામુ નકલ કરો</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>નકલ &amp; લેબલ</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>અલ્પવિરામ થી જુદા પડલી માહિતી ની યાદી (*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ચિઠ્ઠી</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>સરનામુ</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>નિકાસ ની પ્ર્રાક્રિયા નિષ્ફળ ગયેલ છે</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp; નિકાસ કરો</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>હાલ માં પસંદ કરેલ માહિતી ને ફાઇલમાં નિકાસ કરો</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>
